summaryrefslogtreecommitdiff
path: root/libgfortran/generated/spread_c16.c
diff options
context:
space:
mode:
Diffstat (limited to 'libgfortran/generated/spread_c16.c')
-rw-r--r--libgfortran/generated/spread_c16.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libgfortran/generated/spread_c16.c b/libgfortran/generated/spread_c16.c
index 46789ca8adc..e7aff077f2b 100644
--- a/libgfortran/generated/spread_c16.c
+++ b/libgfortran/generated/spread_c16.c
@@ -101,8 +101,8 @@ spread_c16 (gfc_array_c16 *ret, const gfc_array_c16 *source,
}
ret->offset = 0;
- /* internal_malloc_size allocates a single byte for zero size. */
- ret->base_addr = internal_malloc_size (rs * sizeof(GFC_COMPLEX_16));
+ /* xmalloc allocates a single byte for zero size. */
+ ret->base_addr = xmalloc (rs * sizeof(GFC_COMPLEX_16));
if (rs <= 0)
return;
}
@@ -244,7 +244,7 @@ spread_scalar_c16 (gfc_array_c16 *ret, const GFC_COMPLEX_16 *source,
if (ret->base_addr == NULL)
{
- ret->base_addr = internal_malloc_size (ncopies * sizeof (GFC_COMPLEX_16));
+ ret->base_addr = xmalloc (ncopies * sizeof (GFC_COMPLEX_16));
ret->offset = 0;
GFC_DIMENSION_SET(ret->dim[0], 0, ncopies - 1, 1);
}